# eric7.WebBrowser.SpeedDial.PageThumbnailer

Module implementing an object to create a thumbnail image of a web site.

### Global Attributes

None

### Classes

PageThumbnailer | Class implementing a thumbnail creator for web sites.

### Functions

None

## PageThumbnailer

Class implementing a thumbnail creator for web sites.

### Signals

thumbnailCreated(QPixmap)
  emitted after the thumbnail has been created

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

PageThumbnailer | Constructor
__createThumbnail | Private slot creating the thumbnail of the web site.
__grabThumbnail | Private slot to grab the thumbnail image from the view.
loadTitle | Public method to check, if the title is loaded from the web site.
setLoadTitle | Public method to set a flag indicating to load the title from the web site.
setSize | Public method to set the size of the image.
setUrl | Public method to set the URL of the site to be thumbnailed.
start | Public method to start the thumbnailing action.
title | Public method to get the title of the thumbnail.
url | Public method to get the URL of the thumbnail.

### Static Methods

None

#### PageThumbnailer (Constructor)

PageThumbnailer(parent=None)

Constructor

parent
  reference to the parent object (QObject)

#### PageThumbnailer.__createThumbnail

__createThumbnail(status)

Private slot creating the thumbnail of the web site.

status
  flag indicating a successful load of the web site (boolean)

#### PageThumbnailer.__grabThumbnail

__grabThumbnail()

Private slot to grab the thumbnail image from the view.

#### PageThumbnailer.loadTitle

loadTitle()

Public method to check, if the title is loaded from the web site.

Return:
  flag indicating, that the title is loaded (boolean)

#### PageThumbnailer.setLoadTitle

setLoadTitle(load)

Public method to set a flag indicating to load the title from the web site.

load
  flag indicating to load the title (boolean)

#### PageThumbnailer.setSize

setSize(size)

Public method to set the size of the image.

size
  size of the image (QSize)

#### PageThumbnailer.setUrl

setUrl(url)

Public method to set the URL of the site to be thumbnailed.

url
  URL of the web site (QUrl)

#### PageThumbnailer.start

start()

Public method to start the thumbnailing action.

#### PageThumbnailer.title

title()

Public method to get the title of the thumbnail.

Return:
  title of the thumbnail (string)

#### PageThumbnailer.url

url()

Public method to get the URL of the thumbnail.

Return:
  URL of the thumbnail (QUrl)

Up